@@ -196,7 +196,7 @@ template <unsigned DIM> int MZone<DIM>::zoneData()
   }
 
   //--Now loop through all elements again and do same thing for all elements
-  //with
+  // with
   //--index set to 0
 
   for(ElementVec::iterator eVecIt = elemVec.begin(); eVecIt != eVecEnd;
@@ -589,8 +589,6 @@ void updateBoVec<2, MEdge>(
        *--------------------------------------------------------------------*/
 
       {
-        // Get the edge entities that are connected to the vertex
-        std::vector<GEdge *> gEdgeList = ent->edges();
         // Find edge entities that are connected to elements in the zone
         std::vector<std::pair<GEdge *, int> > useGEdge;
         const int nFace = faces.size();
@@ -613,7 +611,7 @@ void updateBoVec<2, MEdge>(
         }
 
         //--'useGEdge' now contains the edge entities that will be used to
-        //determine
+        // determine
         //--the normals
 
         switch(useGEdge.size()) {
@@ -828,7 +826,7 @@ void updateBoVec<3, MFace>(
         }
 
         //--Get a list of face entities connected to the 'vertex' that are also
-        //in the
+        // in the
         //--zone
 
         std::list<const GFace *> useGFace;
@@ -840,7 +838,7 @@ void updateBoVec<3, MFace>(
             MFace mFace =
               faces[iFace].parentElement->getFace(faces[iFace].parentFace);
             const int nVOnF = mFace.getNumVertices();
-            int vertexOnF; // The index of 'vertex' in the face
+            int vertexOnF = 0; // The index of 'vertex' in the face
             for(int iVOnF = 0; iVOnF != nVOnF; ++iVOnF) {
               const MVertex *const vertex2 = mFace.getVertex(iVOnF);
               if(vertex == vertex2)
@@ -864,8 +862,8 @@ void updateBoVec<3, MFace>(
             //   also the unlikely case where the two other MVertex are both on
             //   edges ... and the MElement is still on the GFace.
             if(!matchedFace && (3 == nVOnF)) {
-              const MVertex *vertex2;
-              const MVertex *vertex3;
+              const MVertex *vertex2 = 0;
+              const MVertex *vertex3 = 0;
               switch(vertexOnF) {
               case 0:
                 vertex2 = mFace.getVertex(1);
@@ -880,38 +878,44 @@ void updateBoVec<3, MFace>(
                 vertex3 = mFace.getVertex(1);
                 break;
               }
-              const GEntity *const ent2 = vertex2->onWhat();
-              const GEntity *const ent3 = vertex3->onWhat();
-              if(ent2->dim() == 1 && ent3->dim() == 1) {
-                // Which GFace is bounded by edges ent2 and ent3?
-                for(std::list<GFace *>::const_iterator gFIt = gFaceList.begin();
-                    gFIt != gFaceList.end(); ++gFIt) {
-                  gEdgeList = (*gFIt)->edges();
-                  if((std::find(gEdgeList.begin(), gEdgeList.end(), ent2) !=
-                      gEdgeList.end()) &&
-                     (std::find(gEdgeList.begin(), gEdgeList.end(), ent3) !=
-                      gEdgeList.end())) {
-                    // Edges ent2 and ent3 bound this face
-                    useGFace.push_back(*gFIt);
-                    break;
+              if(vertex2 && vertex3) {
+                const GEntity *const ent2 = vertex2->onWhat();
+                const GEntity *const ent3 = vertex3->onWhat();
+                if(ent2 && ent3) {
+                  if(ent2->dim() == 1 && ent3->dim() == 1) {
+                    // Which GFace is bounded by edges ent2 and ent3?
+                    for(std::list<GFace *>::const_iterator gFIt =
+                          gFaceList.begin();
+                        gFIt != gFaceList.end(); ++gFIt) {
+                      gEdgeList = (*gFIt)->edges();
+                      if((std::find(gEdgeList.begin(), gEdgeList.end(), ent2) !=
+                          gEdgeList.end()) &&
+                         (std::find(gEdgeList.begin(), gEdgeList.end(), ent3) !=
+                          gEdgeList.end())) {
+                        // Edges ent2 and ent3 bound this face
+                        useGFace.push_back(*gFIt);
+                        break;
+                      }
+                    }
                   }
-                }
-              }
-              else if(ent->dim() == 1 && (ent2->dim() + ent3->dim() == 1)) {
-                const GEntity *entCmp;
-                if(ent2->dim() == 1)
-                  entCmp = ent2;
-                else
-                  entCmp = ent3;
-                // Which GFace is bounded by entCmp
-                for(std::list<GFace *>::const_iterator gFIt = gFaceList.begin();
-                    gFIt != gFaceList.end(); ++gFIt) {
-                  gEdgeList = (*gFIt)->edges();
-                  if(std::find(gEdgeList.begin(), gEdgeList.end(), entCmp) !=
-                     gEdgeList.end()) {
-                    // Edge entCmp and the original edge bound this face
-                    useGFace.push_back(*gFIt);
-                    break;
+                  else if(ent->dim() == 1 && (ent2->dim() + ent3->dim() == 1)) {
+                    const GEntity *entCmp;
+                    if(ent2->dim() == 1)
+                      entCmp = ent2;
+                    else
+                      entCmp = ent3;
+                    // Which GFace is bounded by entCmp
+                    for(std::list<GFace *>::const_iterator gFIt =
+                          gFaceList.begin();
+                        gFIt != gFaceList.end(); ++gFIt) {
+                      gEdgeList = (*gFIt)->edges();
+                      if(std::find(gEdgeList.begin(), gEdgeList.end(),
+                                   entCmp) != gEdgeList.end()) {
+                        // Edge entCmp and the original edge bound this face
+                        useGFace.push_back(*gFIt);
+                        break;
+                      }
+                    }
                   }
                 }
               }
@@ -923,7 +927,7 @@ void updateBoVec<3, MFace>(
         useGFace.unique();
 
         //--'useGFace' now contains the face entities that connect to vertex.  A
-        //BC
+        // BC
         //--patch will be written for each of them.
 
         for(std::list<const GFace *>::const_iterator gFIt = useGFace.begin();
@@ -1175,9 +1179,9 @@ int MZoneBoundary<DIM>::interiorBoundaryVertices(const int newZoneIndex,
       // are all unique.
       const typename MZone<DIM>::BoFaceMap::const_iterator *zFace =
         &zoneVertData.faces[0];
-      for(int nZFace = zoneVertData.faces.size(); nZFace--;) {
+      for(unsigned nZFace = zoneVertData.faces.size(); nZFace--;) {
         bool foundMatch = false;
-        for(unsigned int iGFace = 0; iGFace != nGFace; ++iGFace) {
+        for(unsigned iGFace = 0; iGFace != nGFace; ++iGFace) {
           // NBN: face is now a pointer, so need to de-reference
           // if((*zFace)->first ==  globalVertData.faces[iGFace].face )
           if(globalVertData.faces[iGFace].face) {
