@@ -17,6 +17,18 @@
 #include "GRegion.h"
 #include "SPoint3.h"
 #include "SBoundingBox3d.h"
+#include "MFaceHash.h"
+#include "MEdgeHash.h"
+
+// TODO C++11 remove this nasty stuff
+#if __cplusplus >= 201103L
+#include <unordered_map>
+#define hashmapMFace std::unordered_map<MFace, int, Hash_Face, Equal_Face>
+#define hashmapMEdge std::unordered_map<MEdge, int, Hash_Edge, Equal_Edge>
+#else
+#define hashmapMFace std::map<MFace, int, Less_Face>
+#define hashmapMEdge std::map<MEdge, int, Less_Edge>
+#endif
 
 template <class scalar> class simpleFunction;
 
@@ -41,7 +53,8 @@ private:
   std::set<GFace *, GEntityLessThan> _chainFaces;
   std::set<GEdge *, GEntityLessThan> _chainEdges;
   std::set<GVertex *, GEntityLessThan> _chainVertices;
-
+  hashmapMEdge _mapEdgeNum;
+  hashmapMFace _mapFaceNum;
   // the maximum vertex and element id number in the mesh
   std::size_t _maxVertexNum, _maxElementNum;
   std::size_t _checkPointedMaxVertexNum, _checkPointedMaxElementNum;
@@ -226,6 +239,11 @@ public:
     maxe = _checkPointedMaxElementNum;
   }
 
+  // number the edges
+  int addMEdge(const MEdge &edge);
+  //number the faces
+  int addMFace(const MFace &face);
+
   // renumber mesh vertices and elements in a continuous sequence (this
   // invalidates the mesh caches)
   void renumberMeshVertices();
@@ -642,7 +660,7 @@ public:
   int readSTL(const std::string &name, double tolerance = 1.e-3);
   int writeSTL(const std::string &name, bool binary = false,
                bool saveAll = false, double scalingFactor = 1.0,
-               bool oneSolidPerSurface = false);
+               int oneSolidPerSurface = 0);
 
   // PLY(2) format (ascii text format)
   int readPLY(const std::string &name);
