@@ -167,6 +167,11 @@ public:
     return e[edge][vert];
   }
   virtual int numCommonNodesInDualGraph(const MElement *const other) const;
+  virtual int getVertexSolin(int numEdge, int numVertex){
+    static const int eSolin[3][2] = {{0, 1}, {1, 2}, {2, 0}};
+    return getVertex(eSolin[numEdge][numVertex])->getNum();
+  }
+  virtual MFace getFaceSolin(int numFace){return getFace(numFace);}
 };
 
 /*
