@@ -1,10 +1,10 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _SBOUNDING_BOX_3D_H_
-#define _SBOUNDING_BOX_3D_H_
+#ifndef SBOUNDING_BOX_3D_H
+#define SBOUNDING_BOX_3D_H
 
 #include <float.h>
 #include "SPoint3.h"
