@@ -17,7 +17,7 @@
 #include "meshGFaceDelaunayInsertion.h"
 #include "qualityMeasures.h"
 
-double _COS_N(BDS_Point *_p1, BDS_Point *_p2, BDS_Point *_p3, GFace *gf)
+static double _cos_N(BDS_Point *_p1, BDS_Point *_p2, BDS_Point *_p3, GFace *gf)
 {
   double n[3];
   normal_triangle(_p1, _p2, _p3, n);
@@ -31,12 +31,15 @@ double _COS_N(BDS_Point *_p1, BDS_Point *_p2, BDS_Point *_p3, GFace *gf)
 
 double BDS_Face_Validity(GFace *gf, BDS_Face *f)
 {
-  //  if (gf->model()->//  return 1;
   BDS_Point *pts[4];
   f->getNodes(pts);
+  if(!pts[0] || !pts[1] || !pts[2]){
+    Msg::Error("Null point in face validity");
+    return 0.;
+  }
   if(pts[0]->degenerated + pts[1]->degenerated + pts[2]->degenerated < 2) {
     double qa1 = qmTriangle::gamma(pts[0], pts[1], pts[2]);
-    return qa1 * _COS_N(pts[0], pts[1], pts[2], gf);
+    return qa1 * _cos_N(pts[0], pts[1], pts[2], gf);
   }
   return 1.0;
 }
@@ -93,17 +96,13 @@ void outputScalarField(std::vector<BDS_Face *> &t, const char *iii, int param,
     BDS_Point *pts[4];
     if(!(*tit)->deleted) {
       (*tit)->getNodes(pts);
-      // double v = BDS_Face_Validity (gf, *tit);
       if(!param) {
-	//        if(pts[0]->degenerated + pts[1]->degenerated + pts[2]->degenerated <
-	//           2) {
           fprintf(f,
                   "ST(%22.15E,%22.15E,%22.15E,%22.15E,%22.15E,%22.15E,%22.15E,%"
                   "22.15E,%22.15E){%g,%g,%g};\n",
                   pts[0]->X, pts[0]->Y, pts[0]->Z, pts[1]->X, pts[1]->Y,
                   pts[1]->Z, pts[2]->X, pts[2]->Y, pts[2]->Z,
                   (double)pts[0]->iD, (double)pts[1]->iD, (double)pts[2]->iD);
-	  //        }
       }
       if(param && gf) {
         if(pts[0]->degenerated + pts[1]->degenerated + pts[2]->degenerated >
@@ -113,21 +112,18 @@ void outputScalarField(std::vector<BDS_Face *> &t, const char *iii, int param,
           fprintf(f, "SQ(%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g){%g,%g,%g,%g};\n",
                   pts[1]->u, pts[1]->v, 0.0, pts[2]->u, pts[2]->v, 0.0,
                   pts[2]->u, pts[0]->v, 0.0, pts[1]->u, pts[0]->v, 0.0,
-                  //		  v,v,v,v);
                   (double)pts[1]->iD, (double)pts[2]->iD, (double)pts[0]->iD,
                   (double)pts[0]->iD);
         else if(pts[1]->degenerated)
           fprintf(f, "SQ(%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g){%g,%g,%g,%g};\n",
                   pts[2]->u, pts[2]->v, 0.0, pts[0]->u, pts[0]->v, 0.0,
                   pts[0]->u, pts[1]->v, 0.0, pts[2]->u, pts[1]->v, 0.0,
-                  // v,v,v,v);
                   (double)pts[2]->iD, (double)pts[0]->iD, (double)pts[1]->iD,
                   (double)pts[1]->iD);
         else if(pts[2]->degenerated)
           fprintf(f, "SQ(%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g){%g,%g,%g,%g};\n",
                   pts[0]->u, pts[0]->v, 0.0, pts[1]->u, pts[1]->v, 0.0,
                   pts[1]->u, pts[2]->v, 0.0, pts[0]->u, pts[2]->v, 0.0,
-                  // v,v,v,v);
                   (double)pts[0]->iD, (double)pts[1]->iD, (double)pts[2]->iD,
                   (double)pts[2]->iD);
         else {
@@ -136,7 +132,6 @@ void outputScalarField(std::vector<BDS_Face *> &t, const char *iii, int param,
                   "22.15E,%22.15E){%g,%g,%g};\n",
                   pts[0]->u, pts[0]->v, 0.0, pts[1]->u, pts[1]->v, 0.0,
                   pts[2]->u, pts[2]->v, 0.0,
-                  //		    v,v,v);
                   (double)pts[0]->iD, (double)pts[1]->iD, (double)pts[2]->iD);
         }
       }
@@ -182,6 +177,11 @@ double surface_triangle_param(BDS_Point *p1, BDS_Point *p2, BDS_Point *p3)
   // THIS ASSUMES DEGENERATED EDGES ALONG AXIS U !!!
   // SEEMS TO BE THE CASE WITH OCC
 
+  if(!p1 || !p2 || !p3){
+    Msg::Error("Null point");
+    return 0;
+  }
+
   double c;
   if(p1->degenerated + p2->degenerated + p3->degenerated > 1)
     c = 0; // vector_triangle_parametric(p1, p2, p3, c);
@@ -318,7 +318,7 @@ BDS_Edge *BDS_Mesh::recover_edge_fast(BDS_Point *p1, BDS_Point *p2)
       BDS_Face *f = e->otherFace(t);
       if(!f->e4) {
         BDS_Point *p2b = f->oppositeVertex(e);
-        if(p2 == p2b) {
+        if(p2b && p2 == p2b) {
           if(swap_edge(e, BDS_SwapEdgeTestRecover(), true)) {
             return find_edge(p1, p2->iD);
           }
@@ -343,7 +343,7 @@ BDS_Edge *BDS_Mesh::recover_edge(int num1, int num2, bool &_fatal,
   BDS_Point *p2 = find_point(num2);
 
   if(!p1 || !p2) {
-    Msg::Fatal("Could not find points %d or %d in BDS mesh", num1, num2);
+    Msg::Error("Could not find points %d or %d in BDS mesh", num1, num2);
     return 0;
   }
 
@@ -489,7 +489,7 @@ BDS_Edge *BDS_Mesh::add_edge(int const p1, int const p2)
   BDS_Point *pp2 = find_point(p2);
 
   if(!pp1 || !pp2) {
-    Msg::Fatal("Could not find points %d or %d in BDS mesh", p1, p2);
+    Msg::Error("Could not find points %d or %d in BDS mesh", p1, p2);
     return 0;
   }
   edges.push_back(new BDS_Edge(pp1, pp2));
@@ -502,21 +502,24 @@ BDS_Face *BDS_Mesh::add_triangle(int p1, int p2, int p3)
   BDS_Edge *e1 = add_edge(p1, p2);
   BDS_Edge *e2 = add_edge(p2, p3);
   BDS_Edge *e3 = add_edge(p3, p1);
-  return add_triangle(e1, e2, e3);
+  if(e1 && e2 && e3)
+    return add_triangle(e1, e2, e3);
+  return 0;
 }
 
 BDS_Face *BDS_Mesh::add_triangle(BDS_Edge *e1, BDS_Edge *e2, BDS_Edge *e3)
 {
-  // BDS_Face *tfound = find_triangle(e1, e2, e3);
-  // if(tfound) return tfound;
-
-  BDS_Face *t = new BDS_Face(e1, e2, e3);
-  triangles.push_back(t);
-  return t;
+  if(e1 && e2 && e3){
+    BDS_Face *t = new BDS_Face(e1, e2, e3);
+    triangles.push_back(t);
+    return t;
+  }
+  return 0;
 }
 
 void BDS_Mesh::del_face(BDS_Face *t)
 {
+  if(!t) return;
   t->e1->del(t);
   t->e2->del(t);
   t->e3->del(t);
@@ -526,6 +529,7 @@ void BDS_Mesh::del_face(BDS_Face *t)
 
 void BDS_Mesh::del_edge(BDS_Edge *e)
 {
+  if(!e) return;
   e->p1->del(e);
   e->p2->del(e);
   e->deleted = true;
@@ -533,8 +537,9 @@ void BDS_Mesh::del_edge(BDS_Edge *e)
 
 void BDS_Mesh::del_point(BDS_Point *p)
 {
-  points.erase(p);
-  delete p;
+  if(!p) return;
+  if(points.erase(p))
+    delete p;
 }
 
 void BDS_Mesh::add_geom(int p1, int p2)
@@ -548,6 +553,8 @@ void BDS_Edge::computeNeighborhood(BDS_Point *pts1[4], BDS_Point *pts2[4],
                                    BDS_Point *oface[2]) const
 {
   oface[0] = oface[1] = 0;
+  pts1[0] = pts1[1] = pts1[2] = pts1[3] = 0;
+  pts2[0] = pts2[1] = pts2[2] = pts2[3] = 0;
   if(faces(0)) {
     faces(0)->getNodes(pts1);
     if(pts1[0] != p1 && pts1[0] != p2)
@@ -709,11 +716,13 @@ bool BDS_Mesh::split_edge(BDS_Edge *e, BDS_Point *mid)
   BDS_Point *p2 = e->p2;
 
   e->oppositeof(op);
+  if(!op[0] || !op[1]) return false;
 
   int CHECK1 = -1, CHECK2 = 46;
 
   if(p1->iD == CHECK1 && p2->iD == CHECK2)
-    printf("splitting edge %d %d opp %d %d new %d\n", p1->iD, p2->iD, op[0]->iD, op[1]->iD,mid->iD);
+    printf("splitting edge %d %d opp %d %d new %d\n",
+           p1->iD, p2->iD, op[0]->iD, op[1]->iD,mid->iD);
 
   double ori0 = fabs(surface_triangle_param(p2, p1, op[0])) +
                 fabs(surface_triangle_param(p2, p1, op[1]));
@@ -725,12 +734,12 @@ bool BDS_Mesh::split_edge(BDS_Edge *e, BDS_Point *mid)
   double eps = 1.e-2;
   if(ori1 < eps * ori0 || ori2 < eps * ori0 || ori3 < eps * ori0 ||
      ori4 < eps * ori0) {
-    //    printf("%g %g %g %g %g\n",ori0,ori1,ori2,ori3,ori4);
-    //    return false;
+    // printf("%g %g %g %g %g\n",ori0,ori1,ori2,ori3,ori4);
+    // return false;
   }
 
   if(p1->iD == CHECK1 && p2->iD == CHECK2)
-    printf("coucou 2 %d %d %d %d\n", p1->iD, p2->iD, op[0]->iD, op[1]->iD);
+    printf("%d %d %d %d\n", p1->iD, p2->iD, op[0]->iD, op[1]->iD);
 
   BDS_Point *pts1[4];
   e->faces(0)->getNodes(pts1);
@@ -1011,17 +1020,15 @@ bool BDS_SwapEdgeTestNormals::operator()(BDS_Point *_p1, BDS_Point *_p2,
   double qb1 = qmTriangle::gamma(_op1, _op2, _op3);
   double qb2 = qmTriangle::gamma(_oq1, _oq2, _oq3);
 
-  //double mina = std::min(qa1, qa2);
-  //double minb = std::min(qb1, qb2);
-  //  if(minb > 5 * mina) return true;
+  // double mina = std::min(qa1, qa2);
+  // double minb = std::min(qb1, qb2);
+  // if(minb > 5 * mina) return true;
 
-  double OLD = std::min(_ori * qa1 * _COS_N(_p1, _p2, _p3, gf),
-                        _ori * qa2 * _COS_N(_q1, _q2, _q3, gf));
+  double OLD = std::min(_ori * qa1 * _cos_N(_p1, _p2, _p3, gf),
+                        _ori * qa2 * _cos_N(_q1, _q2, _q3, gf));
 
-  double NEW = std::min(_ori * qb1 * _COS_N(_op1, _op2, _op3, gf),
-                        _ori * qb2 * _COS_N(_oq1, _oq2, _oq3, gf));
-
-  //  printf("%d %d %g %g\n",_p1->iD, _p2->iD, OLD, NEW);
+  double NEW = std::min(_ori * qb1 * _cos_N(_op1, _op2, _op3, gf),
+                        _ori * qb2 * _cos_N(_oq1, _oq2, _oq3, gf));
 
   if(OLD < 0.2 && OLD < NEW) return true;
   return false;
@@ -1064,13 +1071,12 @@ bool BDS_Mesh::swap_edge(BDS_Edge *e, const BDS_SwapEdgeTest &theTest,
   BDS_Point *pts1[4];
   BDS_Point *pts2[4];
   e->computeNeighborhood(pts1, pts2, op);
-  //  if (op[0] == op[1])return false;
+  if (!op[0] || !op[1]) return false;
 
   if(p1->iD == CHECK1 && p2->iD == CHECK2) {
-    printf("--------------  e %d %d --> %d %d\n", p1->iD, p2->iD, op[0]->iD,
-           op[1]->iD);
-    printf("--------------  %d %d %d\n", pts1[0]->iD, pts1[1]->iD, pts1[2]->iD);
-    printf("--------------  %d %d %d\n", pts2[0]->iD, pts2[1]->iD, pts2[2]->iD);
+    printf("- e %d %d --> %d %d\n", p1->iD, p2->iD, op[0]->iD, op[1]->iD);
+    printf("-  %d %d %d\n", pts1[0]->iD, pts1[1]->iD, pts1[2]->iD);
+    printf("-  %d %d %d\n", pts2[0]->iD, pts2[1]->iD, pts2[2]->iD);
   }
 
   if(!force && !p1->config_modified && !p2->config_modified &&
@@ -1164,7 +1170,7 @@ int BDS_Edge::numTriangles() const
 {
   // TODO C++11 use std::count_if
   int NT = 0;
-  for(unsigned int i = 0; i < _faces.size(); i++)
+  for(std::size_t i = 0; i < _faces.size(); i++)
     if(faces(i)->numEdges() == 3) NT++;
   return NT;
 }
@@ -1302,6 +1308,10 @@ bool BDS_Mesh::collapse_edge_parametric(BDS_Edge *e, BDS_Point *p, bool force)
   if(e->numfaces() == 2) {
     BDS_Point *oface[2];
     e->oppositeof(oface);
+    if(!oface[0] || !oface[1]){
+      Msg::Error("Null opposite face");
+      return false;
+    }
     for(size_t i = 0; i < oface[0]->edges.size(); i++) {
       if(oface[0]->edges[i]->p1 == oface[0] &&
          oface[0]->edges[i]->p2 == oface[1])
@@ -1348,10 +1358,13 @@ bool BDS_Mesh::collapse_edge_parametric(BDS_Edge *e, BDS_Point *p, bool force)
         pt[0][nt] = (pts[0] == p) ? o : pts[0];
         pt[1][nt] = (pts[1] == p) ? o : pts[1];
         pt[2][nt] = (pts[2] == p) ? o : pts[2];
+        if(!pt[0][nt] || !pt[1][nt] || !pt[2][nt]){
+          Msg::Error("Null point");
+          return false;
+        }
         double snew =
           std::abs(surface_triangle_param(pt[0][nt], pt[1][nt], pt[2][nt]));
         if(!force && snew < .02 * sold) {
-          //	  printf("argh\n");
           return false;
         }
         area_new += snew;
@@ -1373,16 +1386,18 @@ bool BDS_Mesh::collapse_edge_parametric(BDS_Edge *e, BDS_Point *p, bool force)
     }
   }
 
-  // printf("%d triangles 2 add\n",nt);
-
   int kk = 0;
   {
     std::vector<BDS_Edge *> edges(p->edges);
     std::vector<BDS_Edge *>::iterator eit = edges.begin();
     while(eit != edges.end()) {
       (*eit)->p1->config_modified = (*eit)->p2->config_modified = true;
-      ept[0][kk] = ((*eit)->p1 == p) ? o->iD : (*eit)->p1->iD;
-      ept[1][kk] = ((*eit)->p2 == p) ? o->iD : (*eit)->p2->iD;
+      ept[0][kk] = ((*eit)->p1 == p) ? (o ? o->iD : -1) : (*eit)->p1->iD;
+      ept[1][kk] = ((*eit)->p2 == p) ? (o ? o->iD : -1) : (*eit)->p2->iD;
+      if(ept[0][kk] < 0 || ept[1][kk] < 0){
+        Msg::Error("Something wrong in edge collapse!");
+        return false;
+      }
       egs[kk++] = (*eit)->g;
       del_edge(*eit);
       ++eit;
@@ -1407,177 +1422,7 @@ bool BDS_Mesh::collapse_edge_parametric(BDS_Edge *e, BDS_Point *p, bool force)
   return true;
 }
 
-#if 0
-
-bool BDS_Mesh::smooth_point_centroid(BDS_Point *p, GFace *gf, bool test_quality)
-{
-  //  return true;
-  //  printf("coucou\n");
- //  if(!p->config_modified) return false;
- if(p->g && p->g->classif_degree <= 1) return false;
- if(p->g && p->g->classif_tag < 0) {
-   p->config_modified = true;
-   return true;
- }
-
- // TODO C++11 if (std::any_of() ) return false;
- std::vector<BDS_Edge *>::iterator eit = p->edges.begin();
- while(eit != p->edges.end()) {
-   if((*eit)->numfaces() == 1) return false;
-   eit++;
- }
-
- /*    TEST    */
- double radius;
- SPoint3 center;
- bool isSphere = gf->isSphere(radius, center);
- //  bool isBSplineSurface = gf->geomType() == GEntity::BSplineSurface;
- double XX = 0, YY = 0, ZZ = 0;
-
- double U = 0;
- double V = 0;
- double LC = 0;
- double oldU = p->u;
- double oldV = p->v;
-
- std::vector<BDS_Face *> ts = p->getTriangles();
-
- double const size_total = p->edges.size();
-
- std::vector<BDS_Edge *>::iterator edge_iterator = p->edges.begin();
- while(edge_iterator != p->edges.end()) {
-   BDS_Edge const *const edge = *edge_iterator;
-   BDS_Point const *const n = edge->othervertex(p);
-
-   double const fact = 1.0;
-
-   U += n->u * fact;
-   V += n->v * fact;
-   XX += n->X;
-   YY += n->Y;
-   ZZ += n->Z;
-   LC += n->lc() * fact;
-   ++edge_iterator;
- }
- U /= size_total;
- V /= size_total;
- LC /= size_total;
- XX /= size_total;
- YY /= size_total;
- ZZ /= size_total;
-
- GPoint gp;
- double uv[2];
- SVector3 normal;
- if(isSphere /*|| isBSplineSurface*/) {
-   gp = gf->closestPoint(SPoint3(XX, YY, ZZ), uv);
-   U = gp.u();
-   V = gp.v();
- }
- else if(gf->geomType() == GEntity::DiscreteSurface) {
-   //    gp = gf->closestPoint(SPoint3(XX, YY, ZZ), uv);
-   //    U = gp.u();
-   //    V = gp.v();
-   discreteFace *df = static_cast<discreteFace *>(gf);
-   if(df) {
-     gp = df->closestPoint(SPoint3(XX, YY, ZZ), LC, &normal);
-     //      gp = gf->closestPoint(SPoint3(XX, YY, ZZ), uv);
-     U = gp.u();
-     V = gp.v();
-     //      double dx = sqrt ((gp.x()-gp2.x())*(gp.x()-gp2.x())+
-     //			(gp.y()-gp2.y())*(gp.y()-gp2.y())+
-     //			(gp.z()-gp2.z())*(gp.z()-gp2.z()));
-     //      if (dx > 1.e-8){
-     //	printf("ERROR %12.5E\n",dx);
-     //	printf("%g %g %g vs. %g %g %g \n",gp2.x(),gp2.y(),gp2.z(),
-     //	       gp.x(),gp.y(),gp.z());
-     //      }
-   }
- }
- else
-   gp = gf->point(U, V);
-
- if(!gp.succeeded()) { return false; }
- //    if (!gf->containsParam(SPoint2(U,V)))return false;
-
- const double oldX = p->X;
- const double oldY = p->Y;
- const double oldZ = p->Z;
-
- double s1 = 0, s2 = 0;
-
- double newWorst = 1.0, oldWorst = 1.0;
-
- std::vector<BDS_Face *>::const_iterator it = ts.begin();
- while(it != ts.end()) {
-   BDS_Face *t = *it;
-   BDS_Point *n[4];
-   t->getNodes(n);
-   p->u = U;
-   p->v = V;
-   double snew = std::abs(surface_triangle_param(n[0], n[1], n[2]));
-   s1 += snew;
-   p->u = oldU;
-   p->v = oldV;
-   double sold = std::abs(surface_triangle_param(n[0], n[1], n[2]));
-   s2 += sold;
-   if(snew < .1 * sold) return false;
-
-   p->X = gp.x();
-   p->Y = gp.y();
-   p->Z = gp.z();
-   newWorst = std::min(newWorst, qmTriangle::gamma(*it));
-   double norm1[3], norm2[3];
-   normal_triangle(n[0], n[1], n[2], norm1);
-   p->X = oldX;
-   p->Y = oldY;
-   p->Z = oldZ;
-   normal_triangle(n[0], n[1], n[2], norm2);
-   oldWorst = std::min(oldWorst, qmTriangle::gamma(*it));
-   double ps;
-   if(gf->geomType() == GEntity::DiscreteSurface) {
-     ps = prosca(norm1, normal);
-     if(ps > 0) return false;
-   }
-   if(isSphere) {
-     double const dx = center.x() - gp.x();
-     double const dy = center.y() - gp.y();
-     double const dz = center.z() - gp.z();
-     ps = dx * norm1[0] + dy * norm1[1] + dz * norm1[2];
-     if(ps < 0) return false;
-   }
-   else {
-     ps = prosca(norm1, norm2);
-     double threshold = 0.5;
-     if(ps < threshold) { return false; }
-   }
-   ++it;
- }
- // printf("%22.15E %22.15E %22.15E\n",s1,s2,std::abs(s2-s1));
- if(std::abs(s2 - s1) > 1.e-14 * (s2 + s1)) return false;
-
- //  if(test_quality && newWorst < oldWorst){
- //    return false;
- //  }
-
- p->u = U;
- p->v = V;
- p->lc() = LC;
- p->X = gp.x();
- p->Y = gp.y();
- p->Z = gp.z();
- eit = p->edges.begin();
- while(eit != p->edges.end()) {
-   (*eit)->update();
-   ++eit;
- }
- return true;
-}
-
-#else
-
 // Tutte's simple smoothing
-// other implementations are coming
 bool BDS_Mesh::smooth_point_centroid(BDS_Point *p, GFace *gf, bool hard)
 {
   // return false;
@@ -1710,7 +1555,7 @@ bool BDS_Mesh::smooth_point_centroid(BDS_Point *p, GFace *gf, bool hard)
     BDS_Face *t = *it;
     BDS_Point *n[4];
     t->getNodes(n);
-    //    OLD = std::min (OLD,_COS_N ( n[0], n[1], n[2], gf));
+    // OLD = std::min (OLD, _cos_N(n[0], n[1], n[2], gf));
     p->u = U;
     p->v = V;
     double snew = std::abs(surface_triangle_param(n[0], n[1], n[2]));
@@ -1761,8 +1606,6 @@ bool BDS_Mesh::smooth_point_centroid(BDS_Point *p, GFace *gf, bool hard)
   return true;
 }
 
-#endif
-
 bool BDS_Mesh::smooth_point_parametric(BDS_Point *const point, GFace *const gf)
 {
   if(!point->config_modified) return false;
@@ -1796,7 +1639,6 @@ bool BDS_Mesh::smooth_point_parametric(BDS_Point *const point, GFace *const gf)
   while(it != triangles.end()) {
     BDS_Face *t = *it;
     if(!test_move_point_parametric_triangle(point, U, V, t)) {
-      //      printf("coucou %g %g -> %g %g\n", point->u, point->v,U,V);
       return false;
     }
     ++it;
