@@ -1,10 +1,10 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _BDS_H_
-#define _BDS_H_
+#ifndef BDS_H
+#define BDS_H
 
 // This is a 2D version of the Bidirectional Data Structure (BDS)
 // of shephard and beall
@@ -206,13 +206,13 @@ public:
   BDS_Face *otherFace(const BDS_Face *f) const
   {
     if(numfaces() != 2) {
-      Msg::Fatal("otherFace wrong, ony %d faces attached to edge %d %d",
+      Msg::Error("otherFace wrong, ony %d faces attached to edge %d %d",
                  numfaces(), p1->iD, p2->iD);
       return 0;
     }
     if(f == _faces[0]) return _faces[1];
     if(f == _faces[1]) return _faces[0];
-    Msg::Fatal("otherFace wrong: the edge does not belong to the face");
+    Msg::Error("otherFace wrong: the edge does not belong to the face");
     return 0;
   }
   void del(BDS_Face *t)
@@ -252,26 +252,26 @@ public:
   BDS_Edge *oppositeEdge(BDS_Point *p)
   {
     if(e4) {
-      Msg::Fatal("oppositeEdge to point %d cannot be applied to a quad", p->iD);
+      Msg::Error("oppositeEdge to point %d cannot be applied to a quad", p->iD);
       return 0;
     }
     if(e1->p1 != p && e1->p2 != p) return e1;
     if(e2->p1 != p && e2->p2 != p) return e2;
     if(e3->p1 != p && e3->p2 != p) return e3;
-    Msg::Fatal("point %d does not belong to this triangle", p->iD);
+    Msg::Error("point %d does not belong to this triangle", p->iD);
     return 0;
   }
   BDS_Point *oppositeVertex(BDS_Edge *e)
   {
     if(e4) {
-      Msg::Fatal("oppositeVertex to edge %d %d cannot be applied to a quad",
+      Msg::Error("oppositeVertex to edge %d %d cannot be applied to a quad",
                  e->p1->iD, e->p2->iD);
       return 0;
     }
     if(e == e1) return e2->commonvertex(e3);
     if(e == e2) return e1->commonvertex(e3);
     if(e == e3) return e1->commonvertex(e2);
-    Msg::Fatal("edge  %d %d does not belong to this triangle", e->p1->iD,
+    Msg::Error("edge  %d %d does not belong to this triangle", e->p1->iD,
                e->p2->iD);
     return 0;
   }
@@ -413,7 +413,7 @@ class BDS_Mesh {
 public:
   int MAXPOINTNUMBER;
   double Min[3], Max[3], LC;
-  BDS_Mesh(int _MAXX = 0) : MAXPOINTNUMBER(_MAXX) {}
+  BDS_Mesh(int MAXX = 0) : MAXPOINTNUMBER(MAXX) {}
   virtual ~BDS_Mesh();
   BDS_Mesh(const BDS_Mesh &other);
   std::set<BDS_GeomEntity *, GeomLessThan> geom;
