@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include <complex>
 #include <string.h>
@@ -82,14 +82,20 @@ void fullVector<std::complex<double> >::setAll(
 
 template <> void fullMatrix<int>::setAll(const fullMatrix<int> &m)
 {
-  if(_r != m._r || _c != m._c) Msg::Fatal("fullMatrix size does not match");
+  if(_r != m._r || _c != m._c) {
+    Msg::Error("fullMatrix size does not match");
+    return;
+  }
   int N = _r * _c;
   for(int i = 0; i < N; ++i) _data[i] = m._data[i];
 }
 
 template <> void fullMatrix<double>::setAll(const fullMatrix<double> &m)
 {
-  if(_r != m._r || _c != m._c) Msg::Fatal("fullMatrix size does not match");
+  if(_r != m._r || _c != m._c) {
+    Msg::Error("fullMatrix size does not match");
+    return;
+  }
   int N = _r * _c;
   int stride = 1;
   F77NAME(dcopy)(&N, m._data, &stride, _data, &stride);
@@ -99,7 +105,10 @@ template <>
 void fullMatrix<std::complex<double> >::setAll(
   const fullMatrix<std::complex<double> > &m)
 {
-  if(_r != m._r || _c != m._c) Msg::Fatal("fullMatrix size does not match");
+  if(_r != m._r || _c != m._c) {
+    Msg::Error("fullMatrix size does not match");
+    return;
+  }
   int N = _r * _c;
   int stride = 1;
   F77NAME(zcopy)(&N, m._data, &stride, _data, &stride);
@@ -371,8 +380,10 @@ template <> bool fullMatrix<double>::invert(fullMatrix<double> &result) const
   if(result.size2() != M || result.size1() != N) {
     if(result._own_data || !result._data)
       result.resize(M, N, false);
-    else
-      Msg::Fatal("FullMatrix: Bad dimension, I cannot write in proxy");
+    else {
+      Msg::Error("FullMatrix: Bad dimension, I cannot write in proxy");
+      return false;
+    }
   }
   result.setAll(*this);
   F77NAME(dgetrf)(&M, &N, result._data, &lda, ipiv, &info);
@@ -582,9 +593,7 @@ template <> bool fullMatrix<double>::invert(fullMatrix<double> &result) const
 
   // inv = transpose of cofactor / Determinant
   for(int i = 0; i < _r; i++) {
-    for(int j = 0; j < _c; j++) {
-      result(j, i) = cofactor(i, j) / det;
-    }
+    for(int j = 0; j < _c; j++) { result(j, i) = cofactor(i, j) / det; }
   }
   return true;
 }
@@ -592,8 +601,8 @@ template <> bool fullMatrix<double>::invert(fullMatrix<double> &result) const
 #endif
 
 template <>
-void fullMatrix<double>::print(const std::string name,
-                               const std::string format) const
+void fullMatrix<double>::print(const std::string &name,
+                               const std::string &format) const
 {
   std::string rformat = (format == "") ? "%12.5E " : format;
   int ni = size1();
@@ -614,8 +623,8 @@ void fullMatrix<double>::print(const std::string name,
 }
 
 template <>
-void fullMatrix<int>::print(const std::string name,
-                            const std::string format) const
+void fullMatrix<int>::print(const std::string &name,
+                            const std::string &format) const
 {
   std::string rformat = (format == "") ? "%12d " : format;
   int ni = size1();
