@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #ifndef PYRAMIDALBASIS_H
 #define PYRAMIDALBASIS_H
@@ -25,9 +25,10 @@ public:
   ~pyramidalBasis();
   virtual void f(double u, double v, double w, double *val) const;
   virtual void f(const fullMatrix<double> &coord, fullMatrix<double> &sf) const;
+  virtual void f(double u, double v, double w, int i, double *val) const;
   virtual void df(double u, double v, double w, double grads[][3]) const;
-  virtual void df(const fullMatrix<double> &coord,
-                  fullMatrix<double> &dfm) const;
+  virtual void df(const fullMatrix<double> &coord, fullMatrix<double> &dfm) const;
+  virtual void df(double u, double v, double w, int i, double grad[3]) const;
   virtual int getNumShapeFunctions() const;
 };
 
