@@ -77,7 +77,7 @@ def ivoidstar(name, value=None, python_value=None, julia_value=None):
     a = arg(name, value, python_value, julia_value,
             "const void *", "const void *", False)
     a.python_arg = "c_void_p(" + name + ")"
-    a.julia_ctype = "Ptr{Nothing}"
+    a.julia_ctype = "Ptr{Cvoid}"
     return a
 
 def ivectorint(name, value=None, python_value=None, julia_value=None):
@@ -882,7 +882,7 @@ namespace {6} {{
 
 cwrap_utils="""
 template<typename t>
-void vector2ptr(const std::vector<t> &v, t **p, size_t *size)
+{1}void vector2ptr(const std::vector<t> &v, t **p, size_t *size)
 {{
   *p = (t*){0}Malloc(sizeof(t) * v.size());
   for(size_t i = 0; i < v.size(); ++i){{
@@ -891,7 +891,7 @@ void vector2ptr(const std::vector<t> &v, t **p, size_t *size)
   *size = v.size();
 }}
 
-void vectorpair2intptr(const {0}::vectorpair &v, int **p, size_t *size)
+{1}void vectorpair2intptr(const {0}::vectorpair &v, int **p, size_t *size)
 {{
   *p = (int*){0}Malloc(sizeof(int) * v.size() * 2);
   for(size_t i = 0; i < v.size(); ++i){{
@@ -901,7 +901,7 @@ void vectorpair2intptr(const {0}::vectorpair &v, int **p, size_t *size)
   *size = v.size() * 2;
 }}
 
-void vectorstring2charptrptr(const std::vector<std::string> &v, char ***p, size_t *size)
+{1}void vectorstring2charptrptr(const std::vector<std::string> &v, char ***p, size_t *size)
 {{
   *p = (char**){0}Malloc(sizeof(char*) * v.size());
   for(size_t i = 0; i < v.size(); ++i){{
@@ -911,7 +911,7 @@ void vectorstring2charptrptr(const std::vector<std::string> &v, char ***p, size_
 }}
 
 template<typename t>
-void vectorvector2ptrptr(const std::vector<std::vector<t> > &v, t ***p, size_t **size, size_t *sizeSize)
+{1}void vectorvector2ptrptr(const std::vector<std::vector<t> > &v, t ***p, size_t **size, size_t *sizeSize)
 {{
   *p = (t**){0}Malloc(sizeof(t*) * v.size());
   *size = (size_t*){0}Malloc(sizeof(size_t) * v.size());
@@ -948,6 +948,8 @@ from math import pi
 {5}_API_VERSION_MAJOR = {3}
 {5}_API_VERSION_MINOR = {4}
 
+__version__ = {5}_API_VERSION
+
 signal.signal(signal.SIGINT, signal.SIG_DFL)
 libdir = os.path.dirname(os.path.realpath(__file__))
 if platform.system() == "Windows":
@@ -1207,7 +1209,7 @@ class API:
                 fcwrap.write(indent + "// " + ("\n" + indent + "// ").join
                              (textwrap.wrap(doc, 80-len(indent))) + "\n")
                 rt = rtype.rcpp_type if rtype else "void"
-                fnameapi = indent + ns.upper() + "_API " + rt + " " + name + "(";
+                fnameapi = indent + "inline " + rt + " " + name + "(";
                 fcwrap.write(fnameapi)
                 if args:
                     fcwrap.write((",\n" + ' ' * len(fnameapi)).join(a.cpp for a in args))
@@ -1241,7 +1243,7 @@ class API:
                                             self.version_minor, ns))
                     fc.write(c_cpp_header.format(self.copyright, self.issues, ns,
                                                  ns.upper()))
-                    fc.write(cwrap_utils.format(ns))
+                    fc.write(cwrap_utils.format(ns, ""))
                     fc.write(c_cpp_utils.format(ns))
                     fc.write("\n")
                     fcwrap.write(cwrap_header.format(self.copyright, self.issues,
@@ -1249,7 +1251,7 @@ class API:
                                                      self.version_major,
                                                      self.version_minor, ns))
                     fcwrap.write("namespace " + ns + " {\n")
-                    s = string.split(cwrap_utils.format(ns), '\n')
+                    s = cwrap_utils.format(ns, "inline ").split('\n')
                     for line in s:
                         fcwrap.write("  " + line + "\n")
                     fcwrap.write("}\n\n")
@@ -1350,7 +1352,7 @@ class API:
             c_name = c_mpath + name[0].upper() + name[1:]
             f.write("ccall((:" + c_name + ", " +
                     ("" if c_mpath == ns else ns + ".") + "lib), " +
-                    ("Nothing" if rtype is None else rtype.rjulia_type) + ",\n" +
+                    ("Cvoid" if rtype is None else rtype.rjulia_type) + ",\n" +
                     " " * 10 + "(" + ", ".join(
                         (tuple(a.julia_ctype for a in args) + ("Ptr{Cint}",))) +
                     ("," if not len(args) else "") + "),\n" +
